@@ -19,8 +19,12 @@
       test_samples <- rsample::complement(splits)
       res_row$model_object[[1]]$set_args(weights = wts[train_samples])
       res_row$model_object[[1]]$fit(df_train)
-      pred <- predict.tidyfit.models(res_row, df_test, .keep_grid_id = TRUE)
-      metrics <- .eval_metrics(pred, res_row$model_object[[1]]$mode, weights = wts[test_samples])
+      if (nrow(df_test) > 0 & !row$return_slices) {
+        pred <- predict.tidyfit.models(res_row, df_test, .keep_grid_id = TRUE)
+        metrics <- .eval_metrics(pred, res_row$model_object[[1]]$mode, weights = wts[test_samples])
+      } else {
+        metrics <- dplyr::tibble(metric = NA, grid_id = NA)
+      }
       res_row <- .unnest_args(res_row)
       res_row <- res_row %>%
         dplyr::mutate(slice_id = id) %>%
