@@ -2,44 +2,23 @@
 
 #' @importFrom dplyr tibble
 
-.resid.glmnet <- function(object, lambda = NULL, ...) {
-  residuals <- dplyr::tibble(
-    residual = object$call$y - drop(predict(object, object$call$x, s = lambda))
-  )
-  return(residuals)
-}
-
-.resid.lm <- function(object, ...) {
+.resid.default <- function(object, ...) {
   residuals <- dplyr::tibble(
     residual = resid(object)
   )
   return(residuals)
 }
 
-.resid.glm <- function(object, ...) {
+.resid.glmnet <- function(object, self = NULL, ...) {
   residuals <- dplyr::tibble(
-    residual = resid(object)
+    residual = object$call$y - drop(predict(object, object$call$x, s = self$args$lambda))
   )
   return(residuals)
 }
 
-.resid.rq <- function(object, ...) {
+.resid.mvr <- function(object, self = NULL, ...) {
   residuals <- dplyr::tibble(
-    residual = resid(object)
-  )
-  return(residuals)
-}
-
-.resid.rlm <- function(object, ...) {
-  residuals <- dplyr::tibble(
-    residual = resid(object)
-  )
-  return(residuals)
-}
-
-.resid.mvr <- function(object, standard_sd = NULL, ...) {
-  residuals <- dplyr::tibble(
-    residual = resid(object)
+    residual = drop(resid(object)[,,self$args$ncomp])
   )
   return(residuals)
 }
@@ -51,13 +30,6 @@
   return(residuals)
 }
 
-.resid.merMod <- function(object, ...) {
-  residuals <- dplyr::tibble(
-    residual = resid(object)
-  )
-  return(residuals)
-}
-
 .resid.shrinkTVP <- function(object, ...) {
   residuals <- dplyr::tibble(
     residual = colMeans(t(resid(object)))
@@ -65,7 +37,7 @@
   return(residuals)
 }
 
-.resid.MSM.lm <- function(object, index_var = NULL, ...) {
+.resid.MSM.lm <- function(object, self = NULL, ...) {
   condMean <- object@Fit@CondMean
   probs <- object@Fit@smoProb[-1,]
   residuals <- dplyr::tibble(
@@ -74,9 +46,9 @@
   return(residuals)
 }
 
-.resid.cv.hfr <- function(object, kappa_grid = NULL, ...) {
+.resid.cv.hfr <- function(object, self = NULL, ...) {
   residuals <- dplyr::tibble(
-    residual = object$y - drop(predict(object, kappa = kappa_grid))
+    residual = object$y - drop(predict(object, kappa = self$args$kappa_grid))
   )
   return(residuals)
 
